@@ -11,10 +11,9 @@ import datetime
 import time
 import json
 import requests
-from dateutil.relativedelta import relativedelta
+from dateutil.relativedelta import relativedelta  # 安装 pip install python-dateutil
 from retrying import retry
 
-
 def datetime_toString(dt: datetime) -> str:
     """
     把datetime转成字符串
@@ -239,12 +238,12 @@ def get_taobao_time():
                     "sysTime1": f"{json_data.get('time')}"}
         else:
             json_data = {"sysTime3": ts_toStr_det(int(time.time())),
-                         "sysTime2": datetime_toString_detail(datetime.datetime.now()),
+                         "sysTime2": datetime_toString(datetime.datetime.now()),
                          "sysTime1": f"{datetime_toTimestamp(datetime.datetime.now())}"}
             return json_data
     except:
         json_data = {"sysTime3": ts_toStr_det(int(time.time())),
-                     "sysTime2": datetime_toString_detail(datetime.datetime.now()),
+                     "sysTime2": datetime_toString(datetime.datetime.now()),
                      "sysTime1": f"{datetime_toTimestamp(datetime.datetime.now())}"}
         return json_data
 
